<?php

require_once('TCPDF/tcpdf.php');

// Monost pidn obrzk.
// define('K_PATH_IMAGES', PATH_HTML . '/images/'); 
// Nastaven fontu a velikosti psma vychaz z pklad dokumentace TCPDF.

class PDF extends TCPDF {

    private $dataHeader = array();
    private $dataFooter = array();
    private $martinHL = false;

    public function pole($text = "", $zarovnaniLev = 15, $style = '', $size = 8, $radkovani = 4, $velikost = 40, $typ = 'C', $align = 'L') {
        $this->setX(0);    
        $this->SetFont('helvetica', $style, $size);
        $this->SetLeftMargin($zarovnaniLev);
        if ($typ == 'M') {
            $this->MultiCell($velikost, 0, $text, 0, $align);
        } else {
            $this->Cell($velikost, 0, $text, 0, 0, $align);
        }
        if ($radkovani !=0 ){
            $this->Line($radkovani);
        }    
// Monost nastaven odsazen textu.          
//$this->SetLeftMargin(15); 
    }

  
    public function etiketapopisek($etiketa = "", $pole = "", $zarovnaniLev = 15,$styleEtiketa = '',$stylePole = '', $size = 8, $radkovani = 4,$velikostEtiketa = 40,$velikostPole = 40, $typEtiketa = 'C',$typPole = 'C', $alignEtiketa = 'L',$alignPole = 'L') {
        $this->setX(0);    
        $this->SetFont('helvetica', $styleEtiketa, $size+1);
        $this->SetLeftMargin($zarovnaniLev);
        if($typEtiketa == 'C'){
            $this->Cell($velikostEtiketa, 0, $etiketa, 0, 0, $alignEtiketa);
        }else{
            $this->MultiCell($velikostEtiketa, 0, $etiketa, 0, $alignEtiketa);
        }
        $this->SetFont('helvetica', $stylePole, $size+1);
        
        if($typPole == 'C'){
            $this->Cell($velikostPole, 0, $pole, 0, 0, $alignPole);
        }else{
            $this->MultiCell($velikostPole, 0, $pole, 0, $alignPole);
        }        
        
        $this->Line($radkovani);
    }
    
    public function group($text = "", $zarovnaniLev = 15, $style = '', $size = 8, $radkovani = 4, $valX = 0, $align = 'L') {            
        $this->SetFont('helvetica', $style, $size);
        $this->setX($valX);        
        $this->SetLeftMargin($zarovnaniLev);        
        $this->Write(0, $text, '', 0, $align, true, 0, false, false, 0);
        if ($radkovani !=0 ){
            $this->Line($radkovani);
        } 
        $this->SetLeftMargin(15);          
    }
    
    function setHeaderLogo($image = '', $imageWidth = PDF_HEADER_LOGO_WIDTH) {
        $this->dataHeader['image'] = $image;
        $this->dataHeader['imageWidth'] = $imageWidth;
    }

    function setHeaderTitle($title = '', $titleSize = '') {
        $this->dataHeader['title'] = $title;
    }

    function setHeaderSubTitle($subTitle = '', $subTitleSize = '') {
        $this->dataHeader['subTitle'] = $subTitle;
    }

    function setHeaderSubTitle2($subTitle = '', $subTitleSize = '') {
        $this->dataHeader['subTitle2'] = $subTitle;
    }

    function setHeaderTextRight($text) {
        $this->dataHeader['text-right'][] = $text;
    }

    function setFooterTextLeft($text) {
        $this->dataFooter['text-left'][] = $text;
    }

    function setMartinHL($val) {
        $this->martinHL = $val;
    }

    //Ourcodeworld. 2017.  Ourcodeworld Carlos Delgado. [Online] jen 2017. ourcodeworld.co/articulos/leer/601/como-implementar-y-usar-fuentes-personalizadas-en-tcpdf.

    // Nastaven vlastnost fontu.
    // function setFontStyle($text){
    // $this->SetFont($this->FontFamily,$text,$this->FontSize);}
    

    /**
     * Tato metoda je pouvna k rendrovn hlaviky dokumentu, 
     * je mon ji zavolat pomoc AddPage(). 
     * Jej chovn je mon nastavit ve td @public.
     */
    public function Header() {

        $this->SetHeaderData($this->dataHeader['image'], $this->dataHeader['imageWidth'], $this->dataHeader['title'], $this->dataHeader['subTitle']);
        // Nastaven nov XObject ablony.
        // if ($this->header_xobjid < 0) {
        $this->header_xobjid = $this->startTemplate($this->w, $this->tMargin);
        $headerfont = $this->getHeaderFont();
        $headerdata = $this->getHeaderData();
        $this->y = $this->header_margin;
        if ($this->rtl) {
            $this->x = $this->w - $this->original_rMargin;
        } else {
            $this->x = $this->original_lMargin;
        }

        if (($headerdata['logo']) AND ($headerdata['logo'] != K_BLANK_IMAGE)) {
            $imgtype = TCPDF_IMAGES::getImageFileType(K_PATH_IMAGES . $headerdata['logo']);
            if (($imgtype == 'eps') OR ($imgtype == 'ai')) {
                $this->ImageEps(K_PATH_IMAGES . $headerdata['logo'], '', '', $headerdata['logo_width']);
            } elseif ($imgtype == 'svg') {
                $this->ImageSVG(K_PATH_IMAGES . $headerdata['logo'], '', '', $headerdata['logo_width']);
            } else {
                $this->Image(K_PATH_IMAGES . $headerdata['logo'], '', '', $headerdata['logo_width']);
            }
            $imgy = $this->getImageRBY();
        } else {
            $imgy = $this->y;
        }

        $cell_height = round(($this->cell_height_ratio * $headerfont[2]) / $this->k, 2);
        // Nastaven potenho odsazen pro textov buky.
        if ($this->getRTL()) {
            $header_x = $this->original_rMargin + ($headerdata['logo_width'] * 1.1);
        } else {
            $header_x = $this->original_lMargin + ($headerdata['logo_width'] * 1.1);
        }
        $cw = $this->w - $this->original_lMargin - $this->original_rMargin - ($headerdata['logo_width'] * 1.1);
        // Zarovnn hlaviky doprava.
        $hwr = 50;
        $cw = $cw - $hwr;
        $this->SetTextColorArray($this->header_text_color);
        // Titulek hlaviky.
        $this->SetFont($headerfont[0], 'BI', $headerfont[2] + 1);
        $this->SetX($header_x);
        $this->Cell($cw, $cell_height, $headerdata['title'], 0, 1, 'C', 0, '', 0);
        // Pidn textu do hlaviky pomoc stringu.
        $this->SetFont($headerfont[0], 'BI', $headerfont[2]);
        $this->SetX($header_x);
        $this->MultiCell($cw, $cell_height, $headerdata['string'], 0, 'C', 0, 1, '', '', true, 0, false, true, 0, 'T', false);

        $this->SetFont($headerfont[0], 'BI', $headerfont[2]);
        $this->SetX($header_x);
        $this->MultiCell($cw, $cell_height, $this->dataHeader['subTitle2'], 0, 'C', 0, 1, '', '', true, 0, false, true, 0, 'T', false);

        // Tisk prav sti dokumentu.
        $this->SetFont($headerfont[0], $headerfont[1], $headerfont[2] - 4);
        $this->y = $this->header_margin;
        $this->SetX($header_x + $cw - 2);
        $textRight = "";
        foreach ($this->dataHeader['text-right'] as $key => $value) {
            $textRight .= $value . "\n";
        }
// Nastaven vky a ky dku a mon parametry. 
// $this->MultiCell($hrWidth, $hrRowHeigt, 'Pag. ' . 
// $this->PageNo() . '/{nb}', 0, 'R', 0);
        $this->MultiCell($hwr, $cell_height, $textRight, 0, 'R', 0, 1, '', '', true, 0, false, true, 0, 'T', false);
        
        
// Monost volby odsazen.
// debug($this->h) + original_rMargin+ footer_margin;
        $this->SetY((2.835 / $this->k) + max($imgy, $this->y));
        if ($this->rtl) {
            $this->SetX($this->original_rMargin);
        } else {
            $this->SetX($this->original_lMargin);
        }
        $this->Cell(($this->w - $this->original_lMargin - $this->original_rMargin), 0, '', 'T', 0, 'C');
        $this->endTemplate();
        // }
        $this->Line($this->original_rMargin, 8, ($this->w - $this->original_lMargin), 8);
        $this->Line($this->original_rMargin, 26, ($this->w - $this->original_lMargin), 26);

        $this->Line($this->original_rMargin, ($this->h - $this->footer_margin + 6), ($this->w - $this->original_lMargin), ($this->h - $this->footer_margin + 6));

        $this->Line($this->original_rMargin, 8, 10, ($this->h - $this->footer_margin + 6));
        $this->Line(($this->w - $this->original_lMargin), 8, ($this->w - $this->original_lMargin), ($this->h - $this->footer_margin + 6));

// Tisk hlaviky ze ablony pro oboustrann tisk. 
// Dev.virtuemart. 2020. Dev.virtuemart. [Online] 2020. dev.virtuemart.net/svn/virtuemart/trunk/virtuemart/components/com_virtuemart/helpers/vmpdf.php
        $x = 0;
        $dx = 0;
        if (!$this->header_xobj_autoreset AND $this->booklet AND (($this->page % 2) == 0)) {
// Upraven odstup pro oboustrann tisk.
            $dx = ($this->original_lMargin - $this->original_rMargin);
        }
        if ($this->rtl) {
            $x = $this->w + $dx;
        } else {
            $x = 0 + $dx;
        }
        // debug($x);
        $this->printTemplate($this->header_xobjid, $x, 0, 0, 0, '', '', false);
        if ($this->header_xobj_autoreset) {
// Zresetovn hlaviky pro umonn tvorby dokumentu na kad nov strnce.
            $this->header_xobjid = -1;
        }

    }

    public function Footer() {
        $cur_y = $this->y - 3;
        $this->SetTextColorArray($this->footer_text_color);
        //Nastaven ohranien buek
        $line_width = (0.85 / $this->k);
        
// Mon nastaven ohranien tisku.
// $this->SetLineStyle(array('width' => 0.85 / 
// $this->k, 'cap' => 'butt', 'join' => 'miter', 
// 'dash' => 0, 'color' => $headerdata['line_color']));

        $this->SetLineStyle(array('width' => $line_width, 'cap' => 'butt', 'join' => 'miter', 'dash' => 0, 'color' => $this->footer_line_color));
        // Tisk rovho kodu a jeho zarovnn v dokumentu.
        $barcode = $this->getBarcode();
        if (!empty($barcode)) {
            $this->Line($line_width);
            $barcode_width = round(($this->w - $this->original_lMargin - $this->original_rMargin) / 3);
            $style = array(
                'position' => $this->rtl ? 'R' : 'L',
                'align' => $this->rtl ? 'R' : 'L',
                'stretch' => false,
                'fitwidth' => true,
                'cellfitalign' => '',
                'border' => false,
                'padding' => 0,
                'fgcolor' => array(0, 0, 0),
                'bgcolor' => false,
                'text' => false
            );
            $this->write1DBarcode($barcode, 'C128', '', $cur_y + $line_width, '', (($this->footer_margin / 3) - $line_width), 0.3, $style, '');
        }
        if (empty($this->pagegroups)) {
            $pagenumtxt = $this->l['w_page'] . ' ' . $this->getAliasNumPage() . ' / ' . $this->getAliasNbPages();
        } else {
            $pagenumtxt = $this->l['w_page'] . ' ' . $this->getPageNumGroupAlias() . ' / ' . $this->getPageGroupAlias();
        }
        $this->SetY($cur_y);

        // Tisk textu vlevo.
        $headerfont = $this->getHeaderFont();
        $this->SetFont($headerfont[0], $headerfont[1], $headerfont[2] - 4);
        $this->SetX($this->original_lMargin + 2);
        $textLeft = "";
        foreach ($this->dataFooter['text-left'] as $key => $value) {
            $textLeft .= $value . "\n";
        }

        $cell_height = round(($this->cell_height_ratio * $headerfont[2]) / $this->k, 2);
        $hwr = 50;
// Nastaven vky a ky dku a mon parametry 
// $this->MultiCell($hrWidth, $hrRowHeigt, 'Pag. ' . 
// $this->PageNo() . '/{nb}', 0, 'R', 0);
        $this->MultiCell($hwr, $cell_height, $textLeft, 0, 'L', 0, 1, '', '', true, 0, false, true, 0, 'T', false);

        $this->SetY($cur_y);
        
        // Tisk sla strnky do patiky.
        if ($this->getRTL()) {
            $this->SetX($this->original_rMargin);
            $this->Cell(0, 0, $pagenumtxt, 'T', 0, 'L');
        } else {
            $this->SetX($this->original_lMargin);
            $this->Cell(0, 15, '', 'T', 0, 'R');
        }

// Zjitn velikosti strnky dokumentu odetenm levho a pravho zarovnn.
        $cw = $this->w - $this->original_lMargin - $this->original_rMargin;
        // Zarovnn hlaviky doprava.
        $hwr = 88;
        $cw = $cw - $hwr;

        $this->SetY(15);
        $this->SetX($cw);
        $this->Cell(101, 15, $this->getAliasRightShift() ." Pag. ". $pagenumtxt, 0, 0, 'R');

        $SITE_TEST = 1;

        if ($SITE_TEST != 0) {
                $txt = "T E S T";
            
            $this->waterMark($txt);
        }

        if ($this->martinHL) {
            $this->SetAlpha(0.1);
            // Otoen o 45 a vytitn vodoznaku.
            $this->StartTransform();
            // Nastaven rotace.
            // $this->Rotate(0, $myX, $myY);
            $this->SetColor('text', 255, 0, 34);
            $this->SetFont("courier", "B", 60);
            $this->Text(60, 50, "HLAVACEK");
            $this->StopTransform();
            // Resetovn prhlednosti na pvodn hodnotu.
            $this->SetAlpha(1);
        }
    }

    function waterMark($text) {
        // Zjitn dlky a ky strnky.
        $myPageWidth = $this->getPageWidth();
        $myPageHeight = $this->getPageHeight();
        // Nalezen stedu strnky a pizpsoben textu.
        $myX = ( $myPageWidth / 2 ) - 90;
        $myY = ( $myPageHeight / 2 ) + 75;
        // Nastaven textu tisku na svtlou barvu.
        $this->SetAlpha(0.21);
        // Otoen o 45 a tisk vodoznaku.
        $this->StartTransform();
        $this->Rotate(45, $myX, $myY);
        $this->SetColor('text', 255, 0, 34);
        $this->SetFont("courier", "B", 60);
        $this->Text($myX, $myY, $text);
        $this->StopTransform();
        // Resetovn prhlednosti na pvodn hodnotu.
        $this->SetAlpha(1);
    }

}
